<?php
class Funnel_Metabox {
    
    /**
     * Constructor.
     */
    public static function init() {
        add_action( 'add_meta_boxes', array( __CLASS__, 'add_metabox'  )        );
        add_action( 'save_post',      array( __CLASS__, 'save_metabox' ), 10, 2 );
        
        // States
        add_action( 'funnel_state_add_form_fields', array( __CLASS__, 'funnel_state_add_form_fields' ), 10, 2 );
        add_action( 'funnel_state_edit_form_fields', array( __CLASS__, 'funnel_state_edit_form_fields' ), 10, 2 );
        add_action( 'edited_funnel_state', array( __CLASS__, 'save_funnel_state' ), 10, 2 );
        add_action( 'create_funnel_state', array( __CLASS__, 'save_funnel_state' ), 10, 2 );
        
        add_filter('manage_funnel_state_custom_column', array( __CLASS__, 'manage_funnel_state_custom_column' ),10,3);
        add_filter( 'manage_edit-funnel_state_columns', array( __CLASS__, 'add_funnel_state_columns' ) );
        
    }
    
    /**
     * Adds the meta box.
     */
    public static function add_metabox() {
        // Leads
        add_meta_box(
            'my-meta-box',
            __( 'User', 'funnel' ),
            array( __CLASS__, 'render_metabox' ),
            'funnel_lead',
            'side',
            'default'
            );
        
        // Pages
        if ( get_option('funnel_pages_enabled', true) ) {
            add_meta_box(
                'funnel-page-meta-box',
                __( 'Funnel', 'funnel' ),
                array( __CLASS__, 'render_metabox_page' ),
                'page',
                'side',
                'default'
                );
        }
    }
    
    /**
     * Renders the meta box.
     */
    public static function render_metabox( $post ) {
        // Add nonce for security and authentication.
        wp_nonce_field( 'custom_nonce_action', 'custom_nonce' );
        
        wp_dropdown_users( array(
            'show_option_all' => 'User associated',
            'selected' => get_post_meta( $post->ID, 'user_id', true ),
            'name' => 'funnel_user'
        ));
    }
    
    /**
     * Renders the meta box in Pages
     */
    public static function render_metabox_page( $post ) {
        // Add nonce for security and authentication.
        wp_nonce_field( 'funnel_page_nonce_action', 'funnel_page_nonce' );
       
        echo '<label>' . __( 'Funnel state when the user visits this page:', 'funnel' ) . '</label>';
        // Display the states
        wp_dropdown_categories(array(
            'taxonomy' => 'funnel_state',
            'class' => 'widefat',
            'hide_empty' => 0,
            'name' => "funnel_user_state",
            'selected' => get_post_meta( $post->ID, 'funnel_user_state', true ),
            'orderby' => 'name',
            'hierarchical' => 1,
            'show_option_all' => "-"
        ));
    }
    
    /**
     * Handles saving the meta box.
     *
     * @param int     $post_id Post ID.
     * @param WP_Post $post    Post object.
     * @return null
     */
    public static function save_metabox( $post_id, $post ) {
        $post_type = get_post_type($post);
        switch ( $post_type ) {
            case 'funnel_lead':
                $nonce_name   = isset( $_POST['custom_nonce'] ) ? $_POST['custom_nonce'] : '';
                $nonce_action = 'custom_nonce_action';
                break;
            case 'page':
                $nonce_name   = isset( $_POST['funnel_page_nonce'] ) ? $_POST['funnel_page_nonce'] : '';
                $nonce_action = 'funnel_page_nonce_action';
                break;
            default:
                $nonce_name = null;
        }
        
        // Check if nonce is set.
        if ( ! isset( $nonce_name ) ) {
            return;
        }
        
        // Check if nonce is valid.
        if ( ! wp_verify_nonce( $nonce_name, $nonce_action ) ) {
            return;
        }
        
        // Check if user has permissions to save data.
        if ( ! current_user_can( 'edit_post', $post_id ) ) {
            return;
        }
        /*
        // Check if not an autosave.
        if ( wp_is_post_autosave( $post_id ) ) {
            return;
        }
        
        // Check if not a revision.
        if ( wp_is_post_revision( $post_id ) ) {
            return;
        }
        */
        
        switch ( $post_type ) {
            case 'funnel_lead':
                $user   = isset( $_POST['funnel_user'] ) ? sanitize_text_field( $_POST['funnel_user'] ) : '';
                update_post_meta( $post_id, 'user_id', $user );
                break;
            case 'page':
                $state  = isset( $_POST['funnel_user_state'] ) ? intval( $_POST['funnel_user_state'] ) : 0;
                if ( $state > 0 ) {
                    update_post_meta( $post_id, 'funnel_user_state', $state );
                } else {
                    delete_post_meta( $post_id, 'funnel_user_state' );
                }
                break;
        }
    }
    
    public static function save_funnel_state( $term_id ) {
        if ( isset( $_POST['color'] ) ) {
            $t_id = $term_id;
            update_term_meta( $t_id, 'color', sanitize_text_field($_POST['color']) );
        }
        
    }
    
    public static function funnel_state_add_form_fields() {
        ?>
		<div class="form-field">
			<label for="color"><?php _e( 'Color', 'funnel' ); ?></label>
			<input type="color" name="color" id="color" value="#ff0000">
		</div>
	<?php
	}
    
	public static function funnel_state_edit_form_fields( $term ) {
	    
	    $t_id = $term->term_id;
	    $term_meta = get_term_meta( $t_id, 'color', true );
	    ?>
		<tr class="form-field">
		<th scope="row" valign="top"><label for="color"><?php _e( 'Color', 'funnel' ); ?></label></th>
			<td>
				<input type="color" name="color" id="color" value="<?php echo esc_attr( $term_meta ) ? esc_attr( $term_meta ) : ''; ?>">
			</td>
		</tr>
	<?php
	}
	
	public static function manage_funnel_state_custom_column( $content, $column_name, $term_id ) {
	    switch ($column_name) {
	        case 'color':
	            $content = '<span style="color:' . get_term_meta( $term_id, 'color', true ) . '">' . get_term_meta( $term_id, 'color', true ) . '</span>';
	            break;
	        default:
	            break;
	    }
	    return $content;
	}
	
	public static function add_funnel_state_columns( $columns ) {
	    $columns['color'] = 'Color';
	    return $columns;
	}
}

Funnel_Metabox::init();
