<?php
/**
 * funnel.php
 *
 * Copyright (c) 2011,2017 Antonio Blanco http://www.ablancodev.com
 *
 * This code is released under the GNU General Public License.
 * See COPYRIGHT.txt and LICENSE.txt.
 *
 * This code is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * This header and all notices must be kept intact.
 *
 * @author Antonio Blanco
 * @package funnel
 * @since funnel 1.0.0
 *
 * Plugin Name: Funnel
 * Plugin URI: http://www.eggemplo.com
 * Description: Organize your users into a funnel.
 * Version: 1.1.5
 * Author: ablancodev
 * Author URI: http://www.ablancodev.com
 * Text Domain: funnel
 * Domain Path: /languages
 * License: GPLv3
 */
if (! defined ( 'FUNNEL_CORE_DIR' )) {
	define ( 'FUNNEL_CORE_DIR', WP_PLUGIN_DIR . '/funnel' );
}
define ( 'FUNNEL_FILE', __FILE__ );

define ( 'FUNNEL_PLUGIN_URL', plugin_dir_url ( FUNNEL_FILE ) );

class Funnel_Plugin {

	public static $notices = array ();


	public static function init() {
		add_action ( 'init', array (
				__CLASS__,
				'wp_init' 
		) );
		add_action ( 'admin_notices', array (
				__CLASS__,
				'admin_notices' 
		) );

		add_action('admin_init', array ( __CLASS__, 'admin_init' ) );

		register_activation_hook( FUNNEL_FILE, array( __CLASS__, 'activate' ) );

	}
	public static function wp_init() {
		load_plugin_textdomain ( 'funnel', null, 'funnel/languages' );

		add_action ( 'admin_menu', array (
				__CLASS__,
				'admin_menu' 
		), 40 );

		require_once 'core/class-funnel-cpt.php';
		require_once 'core/class-funnel-tax.php';
		require_once 'core/class-funnel-wp.php';
		require_once 'core/class-funnel-leads.php';
		require_once 'core/class-funnel-metabox.php';

		// styles & javascript
		add_action ( 'wp_enqueue_scripts', array (
				__CLASS__,
				'wp_enqueue_scripts' 
		) );
	}

	public static function admin_init() {

	}


	public static function wp_enqueue_scripts($page) {
	// css
		wp_register_style ( 'funnel-style', FUNNEL_PLUGIN_URL . '/css/funnel-style.css', array (), '1.0.0' );
		wp_enqueue_style ( 'funnel-style' );


	}

	public static function admin_notices() {
		if (! empty ( self::$notices )) {
			foreach ( self::$notices as $notice ) {
				echo $notice;
			}
		}
	}

	/**
	 * Adds the admin section.
	 */
	public static function admin_menu() {
        add_submenu_page(
            'edit.php?post_type=funnel_lead',
            __ ( 'Settings', 'funnel' ),
            __ ( 'Settings', 'funnel' ),
            'manage_options',
            'funnel_settings',
            array (
                __CLASS__,
                'funnel_menu_settings' 
            )
        );
    }

    public static function funnel_menu_settings()
    {
        // Get the active tab from the $_GET param
        $default_tab = null;
        $tab = isset($_GET['tab']) ? $_GET['tab'] : $default_tab;

        // if submit
        if (isset($_POST["funnel_settings"]) && wp_verify_nonce($_POST["funnel_settings"], "funnel_settings")) {
            switch ($tab) {
                case 'pages': // pages
                    update_option("funnel_pages_enabled", isset($_POST["funnel_pages_enabled"]) ? sanitize_text_field($_POST["funnel_pages_enabled"]) : 0);
                    break;
                case 'referrer':
                    update_option("funnel_referrer_state", intval($_POST["funnel_referrer_state"]));
                    update_option("funnel_referrer_enabled", isset($_POST["funnel_referrer_enabled"]) ? sanitize_text_field($_POST["funnel_referrer_enabled"]) : 0);
                    update_option("funnel_referrer_param", isset($_POST["funnel_referrer_param"]) ? sanitize_text_field($_POST["funnel_referrer_param"]) : '');
                    break;
                default: // Users
                    update_option("funnel_user_to_lead", isset($_POST["funnel_user_to_lead"]) ? sanitize_text_field($_POST["funnel_user_to_lead"]) : 0);
                    update_option("funnel_user_state", intval($_POST["funnel_user_state"]));
                    break;
            }
        }
        $selected = get_option('funnel_user_to_lead', '1') ? ' checked="checked" ' : '';
        ?>
        <!-- Our admin page content should all be inside .wrap -->
        <div class="wrap">
        	<!-- Print the page title -->
        	<h2><?php echo __( 'Funnel', 'funnel' ); ?></h2>
        	<!-- Here are our tabs -->
        	<nav class="nav-tab-wrapper">
        		<a href="?post_type=funnel_lead&page=funnel_settings"
        			class="nav-tab <?php if($tab===null):?>nav-tab-active<?php endif; ?>"><?php _e('Users', 'funnel');?></a>
        		<a href="?post_type=funnel_lead&page=funnel_settings&tab=pages"
        			class="nav-tab <?php if($tab==='pages'):?>nav-tab-active<?php endif; ?>"><?php _e('Pages', 'funnel');?></a>
        		<a href="?post_type=funnel_lead&page=funnel_settings&tab=referrer"
        			class="nav-tab <?php if($tab==='referrer'):?>nav-tab-active<?php endif; ?>"><?php _e('Referrer', 'funnel');?></a>
        	</nav>
        
        	<div class="tab-content">
            <?php
                switch ($tab) :
                    case 'pages':
                        $selected = get_option('funnel_pages_enabled', '1') ? ' checked="checked" ' : '';
                        ?>
                        <form method="post" action="" enctype="multipart/form-data">
                			<div class="">
                				<p>
                					<input type="checkbox" name="funnel_pages_enabled" value="1"
                						<?php echo $selected;?> />
                					<label><?php echo __( "Enable states changes when users visit pages?", 'funnel' );?></label>
                					<label class="description"><?php echo __('From every page you can select the user state.', 'funnel');?></label>
                				</p>
                    			<?php wp_nonce_field ( 'funnel_settings', 'funnel_settings' ); ?>
                				
                				<input type="submit" value="<?php echo __( "Save", 'funnel' );?>"
                					class="button button-primary button-large" />
                			</div>
                		</form>
                        <?php
                        break;
                    case 'referrer':
                        $selected = get_option('funnel_referrer_enabled', '1') ? ' checked="checked" ' : '';
                        ?>
                        <form method="post" action="" enctype="multipart/form-data">
                			<div class="">
                				<p>
                					<input type="checkbox" name="funnel_referrer_enabled" value="1"
                						<?php echo $selected;?> />
                					<label><?php echo __( "Enable states changes when users come from a referrer?", 'funnel' );?></label>
                				</p>
                				<p>
                					<label><?php echo __( 'Destination State when an user is referrer:', 'funnel' );?></label>
                					<?php
                                    wp_dropdown_categories(array(
                                        'taxonomy' => 'funnel_state',
                                        'class' => 'widefat',
                                        'hide_empty' => 0,
                                        'name' => "funnel_referrer_state",
                                        'selected' => get_option('funnel_referrer_state'),
                                        'orderby' => 'name',
                                        'hierarchical' => 1,
                                        'show_option_all' => " "
                                    ));
                                    ?>
                				</p>
                				<p>
                					<label><?php echo __( 'Param name (example, if you use as url "?social", then set "social"', 'funnel' );?></label>
                					<input type="text" name="funnel_referrer_param" value="<?php echo get_option('funnel_referrer_param');?>" />
                				</p>
                				<?php wp_nonce_field ( 'funnel_settings', 'funnel_settings' ); ?>
                				
                				<input type="submit" value="<?php echo __( "Save", 'funnel' );?>"
                					class="button button-primary button-large" />
                			</div>
                		</form>
                        <?php
                        break;
                default:
                        ?>
                <form method="post" action="" enctype="multipart/form-data">
        			<div class="">
        				<p>
        					<input type="checkbox" name="funnel_user_to_lead" value="1"
        						<?php echo $selected;?> />
        					<label><?php echo __( "Are new users leads?", 'funnel' );?></label>
        				</p>
        				<p>
        					<label><?php echo __( 'New users state:', 'funnel' );?></label>
        					<?php
                        wp_dropdown_categories(array(
                            'taxonomy' => 'funnel_state',
                            'class' => 'widefat',
                            'hide_empty' => 0,
                            'name' => "funnel_user_state",
                            'selected' => get_option('funnel_user_state'),
                            'orderby' => 'name',
                            'hierarchical' => 1,
                            'show_option_all' => " "
                        ));
                        ?>
        				</p>
        				
        				<?php wp_nonce_field ( 'funnel_settings', 'funnel_settings' ); ?>
        				
        				<input type="submit" value="<?php echo __( "Save", 'funnel' );?>"
        					class="button button-primary button-large" />
        			</div>
        		</form>
                <?php
                        break;
                endswitch
                ;
                ?>
            </div>
        </div>
        <?php
    }

    /**
     * Plugin activation work.
     */
    public static function activate() {
        // necesitamos crearlas antes
        require_once 'core/class-funnel-tax.php';
        
        $states = get_terms( array(
            'taxonomy' => 'funnel_state',
            'hide_empty' => false,
        ) );
                
        if ( !$states || (sizeof($states)<= 0) ) {
            // If empty, we add AIDA states
            $res = wp_insert_term( 'Attention', 'funnel_state' );
            if ( isset($res['term_id']) ) {
                update_term_meta( $res['term_id'], 'color', '#e22720' );
            }
            
            $res = wp_insert_term( 'Interest', 'funnel_state' );
            if ( isset($res['term_id']) ) {
                update_term_meta( $res['term_id'], 'color', '#ffb423' );
            }
            
            $res = wp_insert_term( 'Desire', 'funnel_state' );
            if ( isset($res['term_id']) ) {
                update_term_meta( $res['term_id'], 'color', '#4e68a5' );
            }
            
            $res = wp_insert_term( 'Action', 'funnel_state' );
            if ( isset($res['term_id']) ) {
                update_term_meta( $res['term_id'], 'color', '#9ccb01' );
            }
            
        }            
	}
}
Funnel_Plugin::init();
